@@ -1,11 +1,13 @@
+{-# LANGUAGE CPP, NoImplicitPrelude #-}
 module Data.Functor.Compat (
   module Base
+, Functor(..)
 , ($>)
 , void
 ) where
 import Data.Functor as Base
 
-#if !MIN_VERSION_base(4,7,0)
+#if !(MIN_VERSION_base(4,7,0))
 import Control.Monad.Compat (void)
 import Data.Function (flip)
 
